@@ -65,8 +65,13 @@ class Scheduler(ABC):
                 self._store.modify_job(job, changes)
         for job in jobs:
             try:
-                job.next_time, job.close_now = job.call_func()
+                start = util.micro_now()
+                tiggers = job.get_next_time()
+                job.next_time, job.close_now = job.call_func(tiggers)
+                self._store.record_job_exec("success", job, util.micro_now() - start, len(tiggers))
             except Exception as e:
+                job.next_time = tiggers[-1]
+                self._store.record_job_exec("failed", job, util.micro_now() - start, 0, str(e))
                 logging.warning("run job %s catch exception(%s)" % (job.job_id, e))
 
         with self._lock.create_lock(60_000) as succ:
@@ -96,8 +101,12 @@ class Scheduler(ABC):
         return jobs
 
     def add_job(self, job: Job):
-        self._store.add_job(job)
-        self._dispatch_event(JobEvent(EVENT_JOB_ADDED, job.job_id))
+        try:
+            self._store.add_job(job)
+            self._dispatch_event(JobEvent(EVENT_JOB_ADDED, job.job_id))
+        except Exception as e:
+            logging.warning("add job failed reason by '%s'" % str(e))
+            pass
 
     def remove_job(self, job):
         remove_job = self._store.remove_job({
@@ -147,7 +156,12 @@ class Scheduler(ABC):
         while self.state != STATE_STOPPED:
             self._event.wait(wait_seconds)
             self._event.clear()
-            wait_seconds = self._process_jobs()
+            try:
+                wait_seconds = self._process_jobs()
+            except KeyboardInterrupt:
+                raise
+            except Exception as e:
+                logging.warning("process job exception '%s'" % str(e))
 
     def wakeup(self):
         self._event.set()
